# add the cluster name here, it will tag non-limulus systems with the host name
%define clustername limulus
# you can make the VNFS name unique by changing the Version below
Version:co7_base


%define releasebase  10
#Use as deafults if no command line inputs
# allow --with[out] <feature> at rpm command line build
%{?_with_basement: %{expand: %%define as_basement 1}}
%{?_with_limulus: %{expand: %%define as_limulus 1}}
%if "1" == "%{as_basement}"
%define targetbase Basement.%{clustername}
%define repobase basement
%else
%define targetbase Limulus
%define repobase limulus 
%endif

Summary:Warewulf Node VNFS
Name: vnfs 
Group:  %{targetbase}/Admin
Release: %{releasebase}.%{targetbase}
License: Copyright 2020 Basement Supercomputing
Source: %{name}-%{version}.tar
URL: www.basement-supercomputing.com
Distribution: CentOS 7
BuildRoot: %{_tmppath}/%{name}-%{version}-root
Vendor: Basement Supercomputing
Packager: deadline@basement-supercomputing.com
%define ver %{PACKAGE_VERSION}-%{PACKAGE_RELEASE}
Requires: warewulf-provision-ohpc, warewulf-vnfs-ohpc
BuildRequires: warewulf-provision-ohpc, warewulf-vnfs-ohpc
Source1: hostfile.%{clustername}
%description
Bootstrap, VNFS, and /var/chroots for Warewulf. The VNFS is a hybrid and
requires /var/chroots to work correctly. 
%prep 
%setup 
%build


# VNFS variables
PACKPATH=%{name}-%{version}
VNFS=%{version}
ETH=eth0
ROOTPW="changeme"
REPOPATH="https://www.limulus-computing.com/download/releases/co/7"
SENSOR_MODULES="it87 coretemp nct6775"

# clean up any old builds that may have broken
/bin/rm -rf  %{_builddir}/$PACKPATH/var/chroots/$VNFS

# create intial vnfs
echo "++ creating intial vnfs"

wwmkchroot centos-7 %{_builddir}/$PACKPATH/var/chroots/$VNFS

# begin customizations
echo "++ creating /etc/ssh/ssh_config"
#root ssh config for host and nodes
cat <<EOF > %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ssh/ssh_config
# Added by Basement VNFS build script
Host n? headnode
   StrictHostKeyChecking no
   CheckHostIP yes
   UsePrivilegedPort no
   Protocol 2
   ForwardX11 yes
   ForwardX11Trusted yes
   UserKnownHostsFile /dev/null
   LogLevel QUIET
   SendEnv LOADEDMODULES NOMODULES
EOF


# Set quiet logging 
sed --in-place "s/#LogLevel INFO/LogLevel QUIET/" %{_builddir}/$PACKPATH/var/chroots/$VNFS//etc/ssh/sshd_config

cat <<EOF >> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ssh/sshd_config
# Added by Basement VNFS build script
AllowTcpForwarding yes
X11Forwarding yes
AcceptEnv LOADEDMODULES NOMODULES
EOF

chmod +r %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ssh/ssh_config

# update node /etc/fstab
echo "++ updating fstab"
cat <<EOF >> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/fstab
# Added by Basement VNFS build script
headnode:/opt/ohpc /opt/ohpc  nfs     nfsvers=3,noatime,nodev,rsize=8192,wsize=8192 0 0
headnode:/home   /home          nfs           nfsvers=3,noatime,nodev,rsize=8192,wsize=8192 0 0
headnode:/var/chroots/$VNFS /vnfs nfs         nfsvers=3,ro,rsize=8192
EOF

echo "++ Add  /opt/ohpc/adminc/etc/ld.so.conf.d/ so node packages can be easily loaded"
# Add /opt/ohpc/adminc/ld.so.conf.d/  so packages can be added without requiring
# a new vnfs.
#echo "++ adding /opt/ohpc/admin/etc/ld.so.conf.d/to /etc/ld.so.conf"
cat <<EOF >>  %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ld.so.conf
include /opt/ohpc/admin/etc/ld.so.conf.d/*.conf
EOF


# set up node and master /etc/hosts

echo "++ updating node and headnode /etc/hosts"
cp $RPM_SOURCE_DIR/hostfile.%{clustername} %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/hosts


echo "++ Add extra repos for addtional RPMS"
# install and enable epel.ohpc,limulus repo in VNFS
yum install -y --installroot="%{_builddir}/$PACKPATH/var/chroots/$VNFS" epel-release
echo REPOPATH=$REPOPATH base = %{repobase}
/bin/rpm -i --root="%{_builddir}/$PACKPATH/var/chroots/$VNFS" $REPOPATH/%{repobase}/x86_64/RPMS/ohpc-release-1.3-2.el7.x86_64.rpm
# make sure we are using current/basement/limulus rep copies from build host
if [ -e %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/yum.repos.d/basement.repo ]; then
  /bin/rm %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/yum.repos.d/basement.repo
fi
if [ -e %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/yum.repos.d/limulus.repo ]; then
  /bin/rm %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/yum.repos.d/limulus.repo
fi
# get the current repo
wget --no-check-certificate -P %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/yum.repos.d/ $REPOPATH/%{repobase}/x86_64/extra/%{repobase}.repo

echo "++ Add addition packages for nodes"
# add packages
yum install -y --installroot="%{_builddir}/$PACKPATH/var/chroots/$VNFS" \
ohpc-base-compute ohpc-slurm-client ntp lmod-ohpc  \
tcl binutils mailx python bzip2-libs ksh tcsh libxml2 apr ntp libconfuse lm_sensors lm_sensors-libs lm_sensors hdparm \
ganglia-gmond-ohpc ssmtp bind-utils ypbind xterm xauth bc  warewulf-monitor-legacy-wulfd bind-utils xterm xauth bc \
gcc gcc-gfortran gcc-c++ glib2-devel gdb libgfortran kernel-tools-libs kernel-tools mrsh-ohpc mrsh-rsh-compat-ohpc \
mrsh-server-ohpc nhc-ohpc libpsm2 kernel-headers kernel-ml compat-opensm-libs infinipath-psm libibverbs


# from old SL6 image (non-ohpc)
#libgfortran tcl binutils mailx python bzip2-libs ksh tcsh libxml2 apr ntp libconfuse lm_sensors-libs lm_sensors hdparm gcc gcc-gfortran gcc-c++ glib2-devel gdb pkgconfig make automake ganglia-gmond modules-node ssmtp open-mx gridengine-execd-node warewulf-monitor-legacy-wulfd bind-utils ypbind xterm xauth bc

# Config PAM so only allow access by users who have an active job associated with the node
echo "account required pam_slurm.so" >> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/pam.d/sshd

# Now setup ntp
echo "++ Configuring /etc/ntp.conf (node time service)"
cat <<EOF > %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ntp.conf
# Added by %{targetbase} VNFS build script
restrict -4 default ignore
restrict localhost
server 10.0.0.1
restrict 10.0.0.1 nomodify
EOF

echo "++ enable ntp, gmond, slurmd, munge"
chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS systemctl enable ntpd
chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS systemctl enable gmond
chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS systemctl enable slurmd
chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS systemctl enable munge

echo "++ Setup ssmtp so nodes can easily mail to headnode"
# Setup ssmtp only if it is still unset
echo "++ Configuring /etc/ssmtp/ssmtp.conf"
if grep "#Hostname" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ssmtp/ssmtp.conf >/dev/null
then
  HOSTNAME=headnode
  echo "Setting mail host for nodes to: $HOSTNAME"
  sed --in-place "s!#Hostname=!Hostname=$HOSTNAME!g"  %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ssmtp/ssmtp.conf
  sed --in-place "s!mailhub=mail!mailhub=$HOSTNAME!g" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/ssmtp/ssmtp.conf
fi


echo "++ Adding Limulus tweaks to start up using systemd"

/bin/mkdir -p %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/%{targetbase}
cat <<EOF >> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/%{targetbase}/%{targetbase}-node-startup.sh
#!/bin/bash
# Added by %{targetbase} for custom startup
# No Services Are Started outside of systemd
# refresh NFS based library paths if they exist
/sbin/ldconfig
# Added by %{targetbase}  to sync time and local clock on boot
# (assumes 10.0.0.1 for the time server/head node)
systemctl stop ntpd
ntpdate 10.0.0.1
clock --systohc
systemctl start ntpd
# create file to avoid constant sshd: pam_lastlog messages in the message log
touch /var/log/lastlog
# Added to get rid of lastlog waring
# Added %{targetbase} for Ethernet tuning (e1000e)
# remove ITR, increase tx and rx ring size
# If we have Intel NICS do some optimization
NIC0DRIVER=\`ethtool -i eth0|grep driver|gawk '{print $2}'\`
NIC1DRIVER=\`ethtool -i eth1|grep driver|gawk '{print $2}'\`
if [ "\$NIC0DRIVER" = "e1000e" ]; then
 ethtool -C eth0 rx-usecs 0
 ethtool -G eth0 rx 4096 tx 4096
fi
if [ "\$NIC1DRIVER" = "e1000e" ]; then
 ethtool -C eth1 rx-usecs 0
 ethtool -G eth1 rx 4096 tx 4096
fi
# test for 10GbE and turn on if present
lspci|grep -s -q ConnectX-3
if [ "\$?" == "0" ];then
  sh /opt/ohpc/admin/etc/config-10G-ip -i eth0
  ifup eth1
fi
touch /root/.%{targetbase}-startup
EOF
chmod u+x %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/%{targetbase}/%{targetbase}-node-startup.sh

# create systemd service file
cat <<EOF >> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/systemd/system/%{targetbase}-node-startup.service
# /etc/systemd/system/my-startup.service
[Service]
Type=oneshot
RemainAfterExit=yes
ExecStart=/etc/%{targetbase}/%{targetbase}-node-startup.sh

[Install]
WantedBy=multi-user.target
[Unit]
Wants=network-online.target
After=network-online.target
EOF
chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS systemctl enable %{targetbase}-node-startup.service



echo "++ Adjust TCP buffers and receive/send memory"
# bump TCP buffers
mkdir -p %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/sysctl.d
cat <<EOF >>%{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/sysctl.d/limulus.conf
# Added by Limulus to increase TCP max buffer limits
net.core.rmem_max = 16777216
net.core.wmem_max = 16777216
# increase Linux autotuning TCP buffer limits
# min, default, and max number of bytes to use
net.ipv4.tcp_rmem = 4096 87380 16777216 
net.ipv4.tcp_wmem = 4096 65536 16777216
# turn off IP6
net.ipv6.conf.all.disable_ipv6 = 1
net.ipv6.conf.default.disable_ipv6 = 1
EOF

# default values 
#  net.ipv4.tcp_rmem = 4096	131072	6291456
#  net.core.rmem_max = 212992

echo "++ Adding halt.local script to put all attached disks in sleep mode on shutdown"
# Add /usr/sbin/halt.local
# Called by systemd halt-local.service
# Limulus drives have independent power from blades, thus put them to sleep when shutting down
 cat <<EOF >%{_builddir}/$PACKPATH/var/chroots/$VNFS/usr/sbin/halt.local
#!/bin/bash
# Added by Basement for Limulus: used to put any node drives in sleep mode
# Placed in VNFS as /usr/sbin/halt.local
# Called by systemd halt-local.service
LIST=\`/sbin/fdisk -l 2> /dev/null|grep bytes|grep dev\/sd |gawk '{print \$2}'|gawk -F: '{print \$1}'\`
for DRIVE in \$LIST
do
echo  Putting \$DRIVE in Sleep Mode
/sbin/hdparm -Y \$DRIVE
done
EOF

#!/bin/bash
# Added by Basement for Limulus: used to put any node drives in sleep mode
# Placed in VNFS as /usr/sbin/halt.local
# Called by systemd halt-local.service
# LIST=`/sbin/fdisk -l 2> /dev/null|grep bytes|grep dev\/sd |gawk '{print $2}'|gawk -F: '{print $1}'`
# for DRIVE in $LIST
# do
# logger  Putting $DRIVE in Sleep Mode
# /sbin/hdparm -Y $DRIVE
# done
# touch /root/.Limulus-shutdown

chmod u+x %{_builddir}/$PACKPATH/var/chroots/$VNFS/usr/sbin/halt.local

echo "++ Configure rsyslog"
# create file to avoid constant sshd: pam_lastlog messages in the message log
touch %{_builddir}/$PACKPATH/var/chroots/$VNFS/var/log/lastlog


# configure remote logging to head node (note use of 10.0.0.1)
# redirect all authpriv.* messages from secure to messages on nodes (i.e. eliminate secure log)
sed --in-place "s/\/var\/log\/secure/\/var\/log\/messages/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
# Enable remote host down queueing defaults
sed --in-place "s/#\$WorkDirectory/\$WorkDirectory/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
sed --in-place "s/#\$ActionQueueFileName/\$ActionQueueFileName/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
sed --in-place "s/#\$ActionQueueMaxDiskSpace/\$ActionQueueMaxDiskSpace/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
sed --in-place "s/#\$ActionQueueSaveOnShutdown/\$ActionQueueSaveOnShutdown/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
sed --in-place "s/#\$ActionQueueType/\$ActionQueueType/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
sed --in-place "s/#\$ActionResumeRetryCount/\$ActionResumeRetryCount/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
sed --in-place "s/#\*\.\*\ \@\@remote-host\:514/\*\.\*\ \@\@10\.0\.0\.1\:514/" %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf

cat << EOF >> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.conf
# send slurmd.log to headnode
module(load="imfile" PollingInterval="10") #needs to be done just once

input(type="imfile"
      File="/var/log/slurmd.log"
      Tag="slurmd"
      Severity="info"
      Facility="local7")
EOF
# make a /var/log/slurmd.log so rsyslog does not complain when node boots
touch %{_builddir}/$PACKPATH/var/chroots/$VNFS/var/log/slurmd.log

# Add rules to keep root service login messages from node messages log
cat <<EOF> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.d/ignore-systemd-logind-root-session.conf
if \$programname == "systemd-logind" and ((\$msg contains "New session" and \$msg contains "of user root") or \$msg contains "Removed session" ) then stop
EOF
cat <<EOF> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.d/ignore-systemd-root-session.conf
if \$programname == "systemd" and (\$msg contains "Started Session" and \$msg contains "of user root") then stop
EOF
cat <<EOF> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.d/ignore-ssh-root-session.conf
if \$programname == "sshd" and ( \$msg contains "session opened for user root" or \$msg contains "session closed for user root") then stop
EOF
cat <<EOF> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.d/ignore-systemd-root-slice-session.conf
if \$programname == "systemd" and \$msg contains "User Slice of root" then stop
EOF
cat <<EOF> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.d/ignore-pam-slurm-access.conf
if \$programname == "pam_slurm" and \$msg contains "access granted for user root" then stop
EOF
# ignore node cron messages, thes messages are stored in /var/log/cron on the node, but
# not transmitted other logs
cat <<EOF> %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/rsyslog.d/ignore-cron-messages.conf
if \$programname == "CROND" and \$msg contains "CMD" then /var/log/cron
if \$programname == "CROND" and \$msg contains "CMD" then stop
EOF

echo "++ Configure log rotation"
# configure log rotate, purge daily, do not rotate, i.e. all logs purged each day
# since everthing goes to head node using rsyslog. Note, wtmp also gets cleared
# but is not sent to host. The node message file (sent to rsyslog host and placed in 
# /var/log/nodes/n*) contains systemd/ssh login information (not for root)
sed --in-place "s/weekly/daily/"  %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/logrotate.conf
sed --in-place "s/rotate 1/rotate 0/"  %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/logrotate.conf
sed --in-place "s/rotate 4/rotate 0/"  %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/logrotate.conf

cat <<EOF > %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/logrotate.d/limulus
# make sure WW and slurmd logs get cleaned up weekly
/var/log/warewulf/messages
/var/log/warewulf/wwgetfiles.log
/var/log/slurmd.log
{
        missingok
        notifempty
        weekly
}
EOF

echo "++ Configure lm_sensors"
# configure lm_sensors
# Currently, $SENSOR_MODULES has all possible modules for Limulus systems
# (both Intel Core and AMD Ryzen) for supported Asus motherboards.
# if the module is not avialable for the motherboard, it just does
# not load (" No such device") 

/bin/cp /etc/sysconfig/lm_sensors /etc/sysconfig/.limulus-lm_sensors.orig
cat <<EOF >>%{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/sysconfig/lm_sensors
HWMON_MODULES="$SENSOR_MODULES"
EOF
chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS systemctl enable lm_sensors

# add a scratch directlty in case the nodes have SSD's
mkdir %{_builddir}/$PACKPATH/var/chroots/$VNFS/scratch 


# fix pam so nodes don't need /etc/shadow
#sed --in-place 's!account.* required.* pam_unix.so!account     required      pam_unix.so  broken_shadow!' %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/pam.d/system-auth
#sed --in-place 's!account.* required.* pam_unix.so!account     required      pam_unix.so  broken_shadow!'  %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/pam.d/password-auth

# turn off plymouth prompt error in /etc/rc.d.rc.sysinit
#sed --in-place 's/PROMPT=yes/PROMPT=no/'   %{_builddir}/$PACKPATH/var/chroots/$VNFS/etc/sysconfig/init

echo "++ create the vnfs"

cat <<EOF> yes.in
yes
EOF

# add the vnfs hybrid directory
# mkdir -p %{_builddir}/$PACKPATH/var/chroots/$VNFS/vnfs
# Ignore hybrid for now becase this is base VNFS
# /bin/mkdir -p /etc/warewulf/vnfs
# cat <<EOF >> /etc/warewulf/vnfs/$VNFS.conf
# hybridize += /usr/X11R6
# hybridize += /usr/lib/locale
# hybridize += /usr/lib64/locale
# hybridize += /usr/include
# hybridize += /usr/share/man
# hybridize += /usr/share/doc
# hybridize += /usr/share/locale
# EOF
# wwvnfs --chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS  --hybridize --hybridpath=/vnfs --hybridizefile=/etc/warewulf/vnfs/$VNFS-hybrid.conf  < yes.in

wwvnfs --chroot %{_builddir}/$PACKPATH/var/chroots/$VNFS < yes.in

# package the VNFS and Bootstrap
echo "++ packaging VNFS, Bootstrap, chroots"

wwsh  vnfs export $VNFS . < yes.in
# done with vnfs so  delete 
wwsh vnfs delete %{version} < yes.in

BACK=`pwd`
cd %{_builddir}/$PACKPATH/var/chroots
tar cvjf $BACK/$VNFS.bz2 $VNFS &> /dev/null
cd $BACK
rm yes.in

%install
VNFS=%{version}
PACKPATH=%{name}-%{version}
pwd
ls
/bin/mkdir -p %{buildroot}/etc/warewulf/vnfs
cp /etc/warewulf/vnfs/$VNFS.conf %{buildroot}/etc/warewulf/vnfs/$VNFS.conf
#/bin/rm /etc/warewulf/vnfs/$VNFS.conf

mkdir -p  %{buildroot}/var/warewulf/%{targetbase}/%{version}
/bin/cp %{version}.bz2  %{buildroot}/var/warewulf/%{targetbase}/%{version}/%{version}.bz2
/bin/cp %{version}.vnfs  %{buildroot}/var/warewulf/%{targetbase}/%{version}/%{version}.vnfs

%post
wwsh vnfs import /var/warewulf/%{targetbase}/%{version}/%{version}.vnfs -c /var/warewulf/%{targetbase}/%{version}  --a=x86_64  &> /dev/null
mkdir -p /var/chroots
cd /var/chroots
tar xvjf /var/warewulf/%{targetbase}/%{version}/%{version}.bz2 &> /dev/null
#import files for nodes
wwsh file import /etc/passwd --origin /etc/passwd &> /dev/null
wwsh file import /etc/shadow --origin /etc/shadow &> /dev/null
wwsh file import /etc/group --origin /etc/group &> /dev/null
wwsh file import /etc/ganglia/gmond.conf --origin /etc/ganglia/gmond.conf &> /dev/null
wwsh file import /etc/resolv.conf --origin /etc/resolv.conf &> /dev/null
wwsh file import /etc/idmapd.conf --origin /etc/idmapd.conf &> /dev/null
wwsh file import /etc/slurm/slurm.conf --origin /etc/slurm/slurm.conf &> /dev/null
wwsh file import /etc/cron.d/report-ganglia-temp --origin /etc/cron.d/report-ganglia-temp &> /dev/null
wwsh file import --origin /etc/warewulf/.Limulus/Limulus-node-startup.sh  --path  /etc/Limulus/Limulus-node-startup.sh &> /dev/null
wwsh file set Limulus-node-startup.sh --mode 0744 &> /dev/null

wwsh file import /etc/slurm/slurm.conf --origin /etc/slurm/slurm.conf &> /dev/null
wwsh file import /etc/munge/munge.key --origin /etc/munge/munge.key &> /dev/null

%postun
cat <<EOF> yes.in
yes
EOF
wwsh vnfs delete %{version} < yes.in &> /dev/null
/bin/rm -r /var/chroots/%{version}
/bin/rm yes.in
%clean
if [ $RPM_BUILD_ROOT != "/" ]; then
  rm -rf $RPM_BUILD_ROOT
fi

%files
#%defattr(-,root,root)
/var/warewulf/%{targetbase}/%{version}/
/etc/warewulf/vnfs/%{version}.conf


